
# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.1] - 2025-06-28

This is the first release

### Added
- `.res` unpacker (only `.res` files that contain files)
- `.qvm` convert to `.qsc`
- `.wav` convert to `.wav` (waveform) with decoding or `ADPCM` encoded sound files.
